===========
corpusboard
===========


.. image:: https://img.shields.io/pypi/v/corpusboard.svg
        :target: https://pypi.python.org/pypi/corpusboard

.. image:: https://img.shields.io/travis/howl-anderson/corpusboard.svg
        :target: https://travis-ci.org/howl-anderson/corpusboard

.. image:: https://readthedocs.org/projects/corpusboard/badge/?version=latest
        :target: https://corpusboard.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Dashboard for CorpusFlow


* Free software: Apache Software License 2.0
* Documentation: https://corpusboard.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
